@@ -10,8 +10,10 @@
 import json
 import os
 
+import click
 import prettytable
 
+from SoftLayer.CLI import exceptions
 from SoftLayer import utils
 
 FALSE_VALUES = ['0', 'false', 'FALSE', 'no', 'False']
@@ -49,7 +51,7 @@ def format_output(data, fmt='table'):  # pylint: disable=R0911,R0912
     # responds to .formatted
     if hasattr(data, 'formatted'):
         if fmt == 'table':
-            return str(data.formatted)
+            return data.formatted
 
     # responds to .separator
     if hasattr(data, 'separator'):
@@ -72,6 +74,7 @@ def format_prettytable(table):
     for i, row in enumerate(table.rows):
         for j, item in enumerate(row):
             table.rows[i][j] = format_output(item)
+
     ptable = table.prettytable()
     ptable.hrules = prettytable.FRAME
     ptable.horizontal_char = '.'
@@ -82,12 +85,15 @@ def format_prettytable(table):
 
 def format_no_tty(table):
     """Converts SoftLayer.CLI.formatting.Table instance to a prettytable."""
+
     for i, row in enumerate(table.rows):
         for j, item in enumerate(row):
             table.rows[i][j] = format_output(item, fmt='raw')
     ptable = table.prettytable()
+
     for col in table.columns:
         ptable.align[col] = 'l'
+
     ptable.hrules = prettytable.NONE
     ptable.border = False
     ptable.header = False
@@ -143,7 +149,7 @@ def active_txn(item):
 
         :param item: An object capable of having an active transaction
     """
-    return transaction_status(item['activeTransaction'])
+    return transaction_status(utils.lookup(item, 'activeTransaction'))
 
 
 def transaction_status(transaction):
@@ -151,7 +157,7 @@ def transaction_status(transaction):
 
         :param item: An object capable of having an active transaction
     """
-    if not transaction.get('transactionStatus'):
+    if not transaction or not transaction.get('transactionStatus'):
         return blank()
 
     return FormattedItem(
@@ -159,27 +165,6 @@ def transaction_status(transaction):
         transaction['transactionStatus'].get('friendlyName'))
 
 
-def valid_response(prompt, *valid):
-    """Prompt user for input.
-
-    Will display a prompt for a command-line user. If the input is in the
-    valid given valid list then it will return True. Otherwise, it will
-    return False. If no input is received from the user, None is returned
-    instead.
-
-    :param string prompt: string prompt to give to the user
-    :param string \\*valid: valid responses
-    """
-    ans = utils.console_input(prompt).lower()
-
-    if ans in valid:
-        return True
-    elif ans == '':
-        return None
-
-    return False
-
-
 def confirm(prompt_str, default=False):
     """Show a confirmation prompt to a command-line user.
 
@@ -187,16 +172,17 @@ def confirm(prompt_str, default=False):
     :param bool default: Default value to True or False
     """
     if default:
-        prompt = '%s [Y/n]: ' % prompt_str
+        default_str = 'y'
+        prompt = '%s [Y/n]' % prompt_str
     else:
-        prompt = '%s [y/N]: ' % prompt_str
+        default_str = 'n'
+        prompt = '%s [y/N]' % prompt_str
 
-    response = valid_response(prompt, 'y', 'yes', 'yeah', 'yup', 'yolo')
+    ans = click.prompt(prompt, default=default_str, show_default=False)
+    if ans.lower() in ('y', 'yes', 'yeah', 'yup', 'yolo'):
+        return True
 
-    if response is None:
-        return default
-
-    return response
+    return False
 
 
 def no_going_back(confirmation):
@@ -208,10 +194,14 @@ def no_going_back(confirmation):
     if not confirmation:
         confirmation = 'yes'
 
-    return valid_response(
-        'This action cannot be undone! '
-        'Type "%s" or press Enter to abort: ' % confirmation,
-        str(confirmation))
+    prompt = ('This action cannot be undone! Type "%s" or press Enter '
+              'to abort' % confirmation)
+
+    ans = click.prompt(prompt, default='', show_default=False)
+    if ans.lower() == str(confirmation):
+        return True
+
+    return False
 
 
 class SequentialOutput(list):
@@ -251,7 +241,6 @@ class Table(object):
         self.columns = columns
         self.rows = []
         self.align = {}
-        self.format = {}
         self.sortby = None
 
     def add_row(self, row):
@@ -274,7 +263,11 @@ class Table(object):
         """Returns a new prettytable instance."""
         table = prettytable.PrettyTable(self.columns)
         if self.sortby:
-            table.sortby = self.sortby
+            if self.sortby in self.columns:
+                table.sortby = self.sortby
+            else:
+                msg = "Column (%s) doesn't exist to sort by" % self.sortby
+                raise exceptions.CLIAbort(msg)
         for a_col, alignment in self.align.items():
             table.align[a_col] = alignment
 
@@ -320,9 +313,92 @@ class FormattedItem(object):
 
     __repr__ = __str__
 
+    # Implement sorting methods.
+    # NOTE(kmcdonald): functools.total_ordering could be used once support for
+    # Python 2.6 is dropped
+    def __eq__(self, other):
+        return self.original == getattr(other, 'original', other)
+
+    def __lt__(self, other):
+        if self.original is None:
+            return True
+
+        other_val = getattr(other, 'original', other)
+        if other_val is None:
+            return False
+        return self.original < other_val
+
+    def __gt__(self, other):
+        return not (self < other or self == other)
+
+    def __le__(self, other):
+        return self < other or self == other
+
+    def __ge__(self, other):
+        return not self < other
+
 
 def _format_python_value(value):
     """If the value has to_python() defined then return that."""
     if hasattr(value, 'to_python'):
         return value.to_python()
     return value
+
+
+def iter_to_table(value):
+    """Convert raw API responses to response tables."""
+    if isinstance(value, list):
+        return _format_list(value)
+    if isinstance(value, dict):
+        return _format_dict(value)
+    return value
+
+
+def _format_dict(result):
+    """Format dictionary responses into key-value table."""
+
+    table = KeyValueTable(['Name', 'Value'])
+    table.align['Name'] = 'r'
+    table.align['Value'] = 'l'
+
+    for key, value in result.items():
+        value = iter_to_table(value)
+        table.add_row([key, value])
+
+    return table
+
+
+def _format_list(result):
+    """Format list responses into a table."""
+
+    if not result:
+        return result
+
+    if isinstance(result[0], dict):
+        return _format_list_objects(result)
+
+    table = Table(["Value"])
+    for item in result:
+        table.add_row([iter_to_table(item)])
+    return table
+
+
+def _format_list_objects(result):
+    """Format list of objects into a table."""
+
+    all_keys = set()
+    for item in result:
+        all_keys = all_keys.union(item.keys())
+
+    all_keys = sorted(all_keys)
+    table = Table(all_keys)
+
+    for item in result:
+        values = []
+        for key in all_keys:
+            value = iter_to_table(item.get(key))
+            values.append(value)
+
+        table.add_row(values)
+
+    return table
