@@ -8,7 +8,6 @@
 import os
 import os.path
 
-from SoftLayer import auth
 from SoftLayer import utils
 
 
@@ -17,17 +16,16 @@ def get_client_settings_args(**kwargs):
 
         :param \\*\\*kwargs: Arguments that are passed into the client instance
     """
-    settings = {
+    timeout = kwargs.get('timeout')
+    if timeout is not None:
+        timeout = float(timeout)
+    return {
         'endpoint_url': kwargs.get('endpoint_url'),
-        'timeout': kwargs.get('timeout'),
-        'auth': kwargs.get('auth'),
+        'timeout': timeout,
         'proxy': kwargs.get('proxy'),
+        'username': kwargs.get('username'),
+        'api_key': kwargs.get('api_key'),
     }
-    username = kwargs.get('username')
-    api_key = kwargs.get('api_key')
-    if username and api_key and not settings['auth']:
-        settings['auth'] = auth.BasicAuthentication(username, api_key)
-    return settings
 
 
 def get_client_settings_env(**_):
@@ -35,14 +33,12 @@ def get_client_settings_env(**_):
 
         :param \\*\\*kwargs: Arguments that are passed into the client instance
     """
-    username = os.environ.get('SL_USERNAME')
-    api_key = os.environ.get('SL_API_KEY')
-    proxy = os.environ.get('https_proxy')
 
-    config = {'proxy': proxy}
-    if username and api_key:
-        config['auth'] = auth.BasicAuthentication(username, api_key)
-    return config
+    return {
+        'proxy': os.environ.get('https_proxy'),
+        'username': os.environ.get('SL_USERNAME'),
+        'api_key': os.environ.get('SL_API_KEY'),
+    }
 
 
 def get_client_settings_config_file(**kwargs):
@@ -58,7 +54,7 @@ def get_client_settings_config_file(**kwargs):
         'username': '',
         'api_key': '',
         'endpoint_url': '',
-        'timeout': '',
+        'timeout': '0',
         'proxy': '',
     })
     config.read(config_files)
@@ -66,16 +62,14 @@ def get_client_settings_config_file(**kwargs):
     if not config.has_section('softlayer'):
         return
 
-    settings = {
+    return {
         'endpoint_url': config.get('softlayer', 'endpoint_url'),
-        'timeout': config.get('softlayer', 'timeout'),
+        'timeout': config.getfloat('softlayer', 'timeout'),
         'proxy': config.get('softlayer', 'proxy'),
+        'username': config.get('softlayer', 'username'),
+        'api_key': config.get('softlayer', 'api_key'),
     }
-    username = config.get('softlayer', 'username')
-    api_key = config.get('softlayer', 'api_key')
-    if username and api_key:
-        settings['auth'] = auth.BasicAuthentication(username, api_key)
-    return settings
+
 
 SETTING_RESOLVERS = [get_client_settings_args,
                      get_client_settings_env,
@@ -86,8 +80,7 @@ def get_client_settings(**kwargs):
     """Parse client settings.
 
     Parses settings from various input methods, preferring earlier values
-    to later ones. Once an 'auth' value is found, it returns the gathered
-    settings. The settings currently come from explicit user arguments,
+    to later ones. The settings currently come from explicit user arguments,
     environmental variables and config files.
 
         :param \\*\\*kwargs: Arguments that are passed into the client instance
@@ -98,6 +91,5 @@ def get_client_settings(**kwargs):
         if settings:
             settings.update((k, v) for k, v in all_settings.items() if v)
             all_settings = settings
-            if all_settings.get('auth'):
-                break
+
     return all_settings
