@@ -13,8 +13,7 @@ IMAGE_MASK = ('id,accountId,name,globalIdentifier,blockDevices,parentId,'
 
 
 class ImageManager(utils.IdentifierMixin, object):
-    """
-    Manages server images
+    """Manages server images.
 
     :param SoftLayer.API.Client client: an API client instance
     """
@@ -26,7 +25,7 @@ class ImageManager(utils.IdentifierMixin, object):
                           self._get_ids_from_name_private]
 
     def get_image(self, image_id, **kwargs):
-        """ Get details about an image
+        """Get details about an image.
 
         :param int image: The ID of the image.
         :param dict \\*\\*kwargs: response-level options (mask, limit, etc.)
@@ -37,14 +36,14 @@ class ImageManager(utils.IdentifierMixin, object):
         return self.vgbdtg.getObject(id=image_id, **kwargs)
 
     def delete_image(self, image_id):
-        """ deletes the specified image.
+        """Deletes the specified image.
 
-        :param int image: The ID of the image.
+        :param int image_id: The ID of the image.
         """
         self.vgbdtg.deleteObject(id=image_id)
 
     def list_private_images(self, guid=None, name=None, **kwargs):
-        """ List all private images.
+        """List all private images.
 
         :param string guid: filter based on GUID
         :param string name: filter based on name
@@ -68,7 +67,7 @@ class ImageManager(utils.IdentifierMixin, object):
         return account.getPrivateBlockDeviceTemplateGroups(**kwargs)
 
     def list_public_images(self, guid=None, name=None, **kwargs):
-        """ List all public images.
+        """List all public images.
 
         :param string guid: filter based on GUID
         :param string name: filter based on name
@@ -89,19 +88,19 @@ class ImageManager(utils.IdentifierMixin, object):
         return self.vgbdtg.getPublicImages(**kwargs)
 
     def _get_ids_from_name_public(self, name):
-        """ Get public images which match the given name """
+        """Get public images which match the given name."""
         results = self.list_public_images(name=name)
         return [result['id'] for result in results]
 
     def _get_ids_from_name_private(self, name):
-        """ Get private images which match the given name """
+        """Get private images which match the given name."""
         results = self.list_private_images(name=name)
         return [result['id'] for result in results]
 
     def edit(self, image_id, name=None, note=None, tag=None):
-        """
-        Edit image related details
-        :param int image: The ID of the image
+        """Edit image related details.
+
+        :param int image_id: The ID of the image
         :param string name: Name of the Image.
         :param string note: Note of the image.
         :param string tag: Tags of the image to be updated to.
@@ -119,3 +118,8 @@ class ImageManager(utils.IdentifierMixin, object):
             return True
         else:
             return False
+
+    def import_image_from_uri(self, data):
+        """Import images which match the given uri."""
+        result = self.vgbdtg.createFromExternalSource(data)
+        return result
