@@ -1,6 +1,6 @@
 """
     SoftLayer.ticket
-    ~~~~~~~~~~~~~~~
+    ~~~~~~~~~~~~~~~~
     Ticket Manager/helpers
 
     :license: MIT, see LICENSE for more details.
@@ -10,8 +10,7 @@ from SoftLayer import utils
 
 
 class TicketManager(utils.IdentifierMixin, object):
-    """
-    Manages account Tickets
+    """Manages support Tickets.
 
     :param SoftLayer.API.Client client: an API client instance
     """
@@ -22,13 +21,13 @@ class TicketManager(utils.IdentifierMixin, object):
         self.ticket = self.client['Ticket']
 
     def list_tickets(self, open_status=True, closed_status=True):
-        """ List all tickets
+        """List all tickets.
 
         :param boolean open_status: include open tickets
         :param boolean closed_status: include closed tickets
         """
-        mask = ('mask[id, title, assignedUser[firstName, lastName],'
-                'createDate,lastEditDate,accountId]')
+        mask = ('id, title, assignedUser[firstName, lastName],'
+                'createDate,lastEditDate,accountId,status')
 
         call = 'getTickets'
         if not all([open_status, closed_status]):
@@ -37,27 +36,26 @@ class TicketManager(utils.IdentifierMixin, object):
             elif closed_status:
                 call = 'getClosedTickets'
 
-        func = getattr(self.account, call)
-        return func(mask=mask)
+        return self.client.call('Account', call, mask=mask)
 
     def list_subjects(self):
-        """ List all tickets"""
+        """List all tickets."""
         return self.client['Ticket_Subject'].getAllObjects()
 
     def get_ticket(self, ticket_id):
-        """ Get details about a ticket
+        """Get details about a ticket.
 
         :param integer id: the ticket ID
         :returns: A dictionary containing a large amount of information about
                   the specified ticket.
 
         """
-        mask = ('mask[id, title, assignedUser[firstName, lastName],'
-                'createDate,lastEditDate,updates[entry],updateCount]')
+        mask = ('id, title, assignedUser[firstName, lastName],status,'
+                'createDate,lastEditDate,updates[entry,editor],updateCount')
         return self.ticket.getObject(id=ticket_id, mask=mask)
 
     def create_ticket(self, title=None, body=None, subject=None):
-        """ Create a new ticket
+        """Create a new ticket.
 
         :param string title: title for the new ticket
         :param string body: body for the new ticket
@@ -75,11 +73,9 @@ class TicketManager(utils.IdentifierMixin, object):
         return created_ticket
 
     def update_ticket(self, ticket_id=None, body=None):
-        """ Update a ticket
+        """Update a ticket.
 
         :param integer ticket_id: the id of the ticket to update
         :param string body: entry to update in the ticket
         """
-
-        ticket = self.ticket.getObject(id=ticket_id)
-        return self.ticket.edit(ticket, body, id=ticket_id)
+        return self.ticket.addUpdate({'entry': body}, id=ticket_id)
