@@ -12,18 +12,29 @@ import time
 
 from SoftLayer.managers import ordering
 from SoftLayer import utils
+# pylint: disable=no-self-use
 
 
 class VSManager(utils.IdentifierMixin, object):
-
-    """
-    Manages Virtual Servers
+    """Manages Virtual Servers.
 
     :param SoftLayer.API.Client client: an API client instance
     :param SoftLayer.managers.OrderingManager ordering_manager: an optional
                                               manager to handle ordering.
                                               If none is provided, one will be
                                               auto initialized.
+
+    Example::
+
+           # Initialize the VSManager.
+           # env variables. These can also be specified in ~/.softlayer,
+           # or passed directly to SoftLayer.Client()
+           # SL_USERNAME = YOUR_USERNAME
+           # SL_API_KEY = YOUR_API_KEY
+           import SoftLayer
+           client = SoftLayer.Client()
+           mgr = SoftLayer.VSManager(client)
+
     """
 
     def __init__(self, client, ordering_manager=None):
@@ -40,11 +51,23 @@ class VSManager(utils.IdentifierMixin, object):
                        memory=None, hostname=None, domain=None,
                        local_disk=None, datacenter=None, nic_speed=None,
                        public_ip=None, private_ip=None, **kwargs):
-        """ Retrieve a list of all virtual servers on the account.
+        """Retrieve a list of all virtual servers on the account.
+
+        Example::
+
+            # Print out a list of hourly instances in the DAL05 data center.
+
+            for vsi in mgr.list_instances(hourly=True, datacenter='dal05'):
+               print vsi['fullyQualifiedDomainName'], vsi['primaryIpAddress']
+
+            # Using a custom object-mask. Will get ONLY what is specified
+            object_mask = "mask[hostname,monitoringRobot[robotStatus]]"
+            for vsi in mgr.list_instances(mask=object_mask,hourly=True):
+                print vsi
 
         :param boolean hourly: include hourly instances
         :param boolean monthly: include monthly instances
-        :param list tags: filter based on tags
+        :param list tags: filter based on list of tags
         :param integer cpus: filter based on number of CPUS
         :param integer memory: filter based on amount of memory
         :param string hostname: filter based on hostname
@@ -57,20 +80,6 @@ class VSManager(utils.IdentifierMixin, object):
         :param dict \\*\\*kwargs: response-level options (mask, limit, etc.)
         :returns: Returns a list of dictionaries representing the matching
                   virtual servers
-
-        ::
-
-           # Print out a list of all hourly instances in the DAL05 data center.
-           # env variables
-           # SL_USERNAME = YOUR_USERNAME
-           # SL_API_KEY = YOUR_API_KEY
-           import SoftLayer
-           client = SoftLayer.Client()
-
-           mgr = SoftLayer.VSManager(client)
-           for vsi in mgr.list_instances(hourly=True, datacenter='dal05'):
-               print vsi['fullyQualifiedDomainName'], vs['primaryIpAddress']
-
         """
         if 'mask' not in kwargs:
             items = [
@@ -88,7 +97,6 @@ class VSManager(utils.IdentifierMixin, object):
                 'datacenter',
                 'activeTransaction.transactionStatus[friendlyName,name]',
                 'status',
-                'billingItem.orderItem.order.userRecord[username]'
             ]
             kwargs['mask'] = "mask[%s]" % ','.join(items)
 
@@ -143,24 +151,22 @@ class VSManager(utils.IdentifierMixin, object):
         return func(**kwargs)
 
     def get_instance(self, instance_id, **kwargs):
-        """ Get details about a virtual server instance
+        """Get details about a virtual server instance.
 
         :param integer instance_id: the instance ID
         :returns: A dictionary containing a large amount of information about
                   the specified instance.
 
-        ::
+        Example::
 
-           # Print out the FQDN and IP address for instance ID 12345.
-           # env variables
-           # SL_USERNAME = YOUR_USERNAME
-           # SL_API_KEY = YOUR_API_KEY
-           import SoftLayer
-           client = SoftLayer.Client()
+            # Print out instance ID 12345.
+            vsi = mgr.get_instance(12345)
+            print vsi
 
-           mgr = SoftLayer.VSManager(client)
-           vsi = mgr.get_instance(12345)
-           print vsi['fullyQualifiedDomainName'], vs['primaryIpAddress']
+            # Print out only FQDN and primaryIP for instance 12345
+            object_mask = "mask[fullyQualifiedDomainName,primaryIpAddress]"
+            vsi = mgr.get_instance(12345, mask=mask)
+            print vsi
 
         """
 
@@ -193,12 +199,12 @@ class VSManager(utils.IdentifierMixin, object):
                 'blockDevices',
                 'blockDeviceTemplateGroup[id, name, globalIdentifier]',
                 'postInstallScriptUri',
-                'userData',
                 '''operatingSystem[passwords[username,password],
                                    softwareLicense.softwareDescription[
                                        manufacturer,name,version,
                                        referenceCode]]''',
                 'hourlyBillingFlag',
+                'userData',
                 'billingItem.recurringFee',
                 'tagReferences[id,tag[name,id]]',
                 'networkVlans[id,vlanNumber,networkSpace]',
@@ -209,52 +215,48 @@ class VSManager(utils.IdentifierMixin, object):
         return self.guest.getObject(id=instance_id, **kwargs)
 
     def get_create_options(self):
-        """ Retrieves the available options for creating a VS.
+        """Retrieves the available options for creating a VS.
 
         :returns: A dictionary of creation options.
 
+        Example::
+
+            # Prints out the create option dictionary
+            options = mgr.get_create_options()
+            print(options)
         """
         return self.guest.getCreateObjectOptions()
 
     def cancel_instance(self, instance_id):
-        """ Cancel an instance immediately, deleting all its data.
+        """Cancel an instance immediately, deleting all its data.
 
         :param integer instance_id: the instance ID to cancel
 
-        ::
+        Example::
 
-           # Cancel for instance ID 12345.
-           # env variables
-           # SL_USERNAME = YOUR_USERNAME
-           # SL_API_KEY = YOUR_API_KEY
-           import SoftLayer
-           client = SoftLayer.Client()
-
-           mgr = SoftLayer.VSManager(client)
-           mgr.cancel_instance(12345)
+            # Cancels instance 12345
+            mgr.cancel_instance(12345)
 
         """
         return self.guest.deleteObject(id=instance_id)
 
     def reload_instance(self, instance_id, post_uri=None, ssh_keys=None):
-        """ Perform an OS reload of an instance with its current configuration.
+        """Perform an OS reload of an instance with its current configuration.
 
         :param integer instance_id: the instance ID to reload
         :param string post_url: The URI of the post-install script to run
                                 after reload
         :param list ssh_keys: The SSH keys to add to the root user
 
-        ::
+        .. warning::
+            Post-provision script MUST be HTTPS for it to be executed.
+            This will reformat the primary drive.
+
+        Example::
 
            # Reload instance ID 12345 then run a custom post-provision script.
-           # env variables
-           # SL_USERNAME = YOUR_USERNAME
-           # SL_API_KEY = YOUR_API_KEY
-           import SoftLayer
-           client = SoftLayer.Client()
-
+           # Post-provision script MUST be HTTPS for it to be executed.
            post_uri = 'https://somehost.com/bootstrap.sh'
-           mgr = SoftLayer.VSManager(client)
            vsi = mgr.reload_instance(12345, post_uri=post_url)
 
         """
@@ -276,7 +278,8 @@ class VSManager(utils.IdentifierMixin, object):
             dedicated=False, public_vlan=None, private_vlan=None,
             userdata=None, nic_speed=None, disks=None, post_uri=None,
             private=False, ssh_keys=None):
-        """ Returns a dict appropriate to pass into Virtual_Guest::createObject
+        """Returns a dict appropriate to pass into Virtual_Guest::createObject
+
             See :func:`create_instance` for a list of available options.
         """
         required = [cpus, memory, hostname, domain]
@@ -332,7 +335,7 @@ class VSManager(utils.IdentifierMixin, object):
         if nic_speed:
             data['networkComponents'] = [{'maxSpeed': nic_speed}]
 
-        if disks and isinstance(disks, list):
+        if disks:
             data['blockDevices'] = [
                 {"device": "0", "diskImage": {"capacity": disks[0]}}
             ]
@@ -354,8 +357,9 @@ class VSManager(utils.IdentifierMixin, object):
         return data
 
     def wait_for_transaction(self, instance_id, limit, delay=1):
-        """ Waits on a VS transaction for the specified amount of time.
-        is really just a wrapper for wait_for_ready(pending=True).
+        """Waits on a VS transaction for the specified amount of time.
+
+        This is really just a wrapper for wait_for_ready(pending=True).
         Provided for backwards compatibility.
 
 
@@ -369,13 +373,14 @@ class VSManager(utils.IdentifierMixin, object):
                                    pending=True)
 
     def wait_for_ready(self, instance_id, limit, delay=1, pending=False):
-        """ Determine if a VS is ready and available.  In some cases
-        though, that can mean that no transactions are running. The default
-        arguments imply a VS is operational and ready for use by having
-        network connectivity and remote access is available.  Setting
-        ``pending=True`` will ensure future API calls
-        against this instance will not error due to pending
-        transactions such as OS Reloads and cancellations.
+        """Determine if a VS is ready and available.
+
+        In some cases though, that can mean that no transactions are running.
+        The default arguments imply a VS is operational and ready for use by
+        having network connectivity and remote access is available. Setting
+        ``pending=True`` will ensure future API calls against this instance
+        will not error due to pending transactions such as OS Reloads and
+        cancellations.
 
         :param int instance_id: The instance ID with the pending transaction
         :param int limit: The maximum amount of time to wait.
@@ -383,10 +388,18 @@ class VSManager(utils.IdentifierMixin, object):
                           Defaults to 1.
         :param bool pending: Wait for pending transactions not related to
                              provisioning or reloads such as monitoring.
+
+        Example::
+
+            # Will return once vsi 12345 is ready, or after 10 checks
+            ready = mgr.wait_for_ready(12345, 10)
         """
-        for count, new_instance in enumerate(itertools.repeat(instance_id),
-                                             start=1):
-            instance = self.get_instance(new_instance)
+        until = time.time() + limit
+        for new_instance in itertools.repeat(instance_id):
+            mask = """id,
+                      lastOperatingSystemReload.id,
+                      activeTransaction.id,provisionDate"""
+            instance = self.get_instance(new_instance, mask=mask)
             last_reload = utils.lookup(instance,
                                        'lastOperatingSystemReload',
                                        'id')
@@ -397,7 +410,7 @@ class VSManager(utils.IdentifierMixin, object):
             reloading = all((
                 active_transaction,
                 last_reload,
-                last_reload == active_transaction
+                last_reload == active_transaction,
             ))
 
             # only check for outstanding transactions if requested
@@ -412,21 +425,72 @@ class VSManager(utils.IdentifierMixin, object):
                     not outstanding]):
                 return True
 
-            if count >= limit:
+            now = time.time()
+            if now >= until:
                 return False
 
-            time.sleep(delay)
+            time.sleep(min(delay, until - now))
 
     def verify_create_instance(self, **kwargs):
-        """ Verifies an instance creation command without actually placing an
-            order. See :func:`create_instance` for a list of available options.
+        """Verifies an instance creation command.
+
+        Without actually placing an order.
+        See :func:`create_instance` for a list of available options.
+
+        Example::
+
+            new_vsi = {
+                'domain': u'test01.labs.sftlyr.ws',
+                'hostname': u'minion05',
+                'datacenter': u'hkg02',
+                'dedicated': False,
+                'private': False,
+                'cpus': 1,
+                'os_code' : u'UBUNTU_LATEST',
+                'hourly': True,
+                'ssh_keys': [1234],
+                'disks': ('100','25'),
+                'local_disk': True,
+                'memory': 1024
+            }
+
+            vsi = mgr.verify_create_instance(**new_vsi)
+            # vsi will be a SoftLayer_Container_Product_Order_Virtual_Guest
+            # if your order is correct. Otherwise you will get an exception
+            print vsi
         """
+        kwargs.pop('tags', None)
         create_options = self._generate_create_dict(**kwargs)
         return self.guest.generateOrderTemplate(create_options)
 
     def create_instance(self, **kwargs):
-        """
-        Creates a new virtual server instance
+        """Creates a new virtual server instance.
+
+        .. warning::
+
+            This will add charges to your account
+
+        Example::
+
+            new_vsi = {
+                'domain': u'test01.labs.sftlyr.ws',
+                'hostname': u'minion05',
+                'datacenter': u'hkg02',
+                'dedicated': False,
+                'private': False,
+                'cpus': 1,
+                'os_code' : u'UBUNTU_LATEST',
+                'hourly': True,
+                'ssh_keys': [1234],
+                'disks': ('100','25'),
+                'local_disk': True,
+                'memory': 1024,
+                'tags': 'test, pleaseCancel'
+            }
+
+            vsi = mgr.create_instance(**new_vsi)
+            # vsi will have the newly created vsi details if done properly.
+            print vsi
 
         :param int cpus: The number of virtual CPUs to include in the instance.
         :param int memory: The amount of RAM to order.
@@ -447,7 +511,7 @@ class VSManager(utils.IdentifierMixin, object):
                                incur a fee on your account.
         :param int public_vlan: The ID of the public VLAN on which you want
                                 this VS placed.
-        :param int private_vlan: The ID of the public VLAN on which you want
+        :param int private_vlan: The ID of the private VLAN on which you want
                                  this VS placed.
         :param list disks: A list of disk capacities for this server.
         :param string post_uri: The URI of the post-install script to run
@@ -456,7 +520,7 @@ class VSManager(utils.IdentifierMixin, object):
                              access to the private network. Defaults to false
         :param list ssh_keys: The SSH keys to add to the root user
         :param int nic_speed: The port speed to set
-        :param string tag: tags to set on the VS as a comma separated list
+        :param string tags: tags to set on the VS as a comma separated list
         """
         tags = kwargs.pop('tags', None)
         inst = self.guest.createObject(self._generate_create_dict(**kwargs))
@@ -465,10 +529,45 @@ class VSManager(utils.IdentifierMixin, object):
         return inst
 
     def create_instances(self, config_list):
-        """ Creates multiple virtual server instances
+        """Creates multiple virtual server instances.
 
         This takes a list of dictionaries using the same arguments as
         create_instance().
+
+        .. warning::
+
+            This will add charges to your account
+
+        Example::
+
+            # Define the instance we want to create.
+            new_vsi = {
+                'domain': u'test01.labs.sftlyr.ws',
+                'hostname': u'multi-test',
+                'datacenter': u'hkg02',
+                'dedicated': False,
+                'private': False,
+                'cpus': 1,
+                'os_code' : u'UBUNTU_LATEST',
+                'hourly': True,
+                'ssh_keys': [87634],
+                'disks': ('100','25'),
+                'local_disk': True,
+                'memory': 1024,
+                'tags': 'test, pleaseCancel'
+            }
+
+            # using .copy() so we can make changes to individual nodes
+            instances = [new_vsi.copy(), new_vsi.copy(), new_vsi.copy()]
+
+            # give each its own hostname, not required.
+            instances[0]['hostname'] = "multi-test01"
+            instances[1]['hostname'] = "multi-test02"
+            instances[2]['hostname'] = "multi-test03"
+
+            vsi = mgr.create_instances(config_list=instances)
+            #vsi will be a dictionary of all the new virtual servers
+            print vsi
         """
         tags = [conf.pop('tags', None) for conf in config_list]
 
@@ -482,13 +581,23 @@ class VSManager(utils.IdentifierMixin, object):
         return resp
 
     def change_port_speed(self, instance_id, public, speed):
-        """ Allows you to change the port speed of a virtual server's NICs.
+        """Allows you to change the port speed of a virtual server's NICs.
+
+        Example::
+
+            #change the Public interface to 10Mbps on instance 12345
+            result = mgr.change_port_speed(instance_id=12345,
+                                        public=True, speed=10)
+            # result will be True or an Exception
 
         :param int instance_id: The ID of the VS
         :param bool public: Flag to indicate which interface to change.
                             True (default) means the public interface.
                             False indicates the private interface.
         :param int speed: The port speed to set.
+
+        .. warning::
+            A port speed of 0 will disable the interface.
         """
         if public:
             func = self.guest.setPublicNetworkInterfaceSpeed
@@ -498,12 +607,12 @@ class VSManager(utils.IdentifierMixin, object):
         return func(speed, id=instance_id)
 
     def _get_ids_from_hostname(self, hostname):
-        """ List VS ids which match the given hostname """
+        """List VS ids which match the given hostname."""
         results = self.list_instances(hostname=hostname, mask="id")
         return [result['id'] for result in results]
 
     def _get_ids_from_ip(self, ip_address):
-        """ List VS ids which match the given ip address """
+        """List VS ids which match the given ip address."""
         try:
             # Does it look like an ip address?
             socket.inet_aton(ip_address)
@@ -520,8 +629,8 @@ class VSManager(utils.IdentifierMixin, object):
             return [result['id'] for result in results]
 
     def edit(self, instance_id, userdata=None, hostname=None, domain=None,
-             notes=None, tag=None):
-        """ Edit hostname, domain name, notes, and/or the user data of a VS
+             notes=None, tags=None):
+        """Edit hostname, domain name, notes, and/or the user data of a VS.
 
         Parameters set to None will be ignored and not attempted to be updated.
 
@@ -531,17 +640,22 @@ class VSManager(utils.IdentifierMixin, object):
         :param string hostname: valid hostname
         :param string domain: valid domain namem
         :param string notes: notes about this particular VS
-        :param string tag: tags to set on the VS as a comma separated list.
+        :param string tags: tags to set on the VS as a comma separated list.
                             Use the empty string to remove all tags.
+        :returns: bool -- True or an Exception
 
+        Example::
+            # Change the hostname on instance 12345 to 'something'
+            result = mgr.edit(instance_id=12345 , hostname="something")
+            #result will be True or an Exception
         """
 
         obj = {}
         if userdata:
             self.guest.setUserMetadata([userdata], id=instance_id)
 
-        if tag is not None:
-            self.guest.setTags(tag, id=instance_id)
+        if tags is not None:
+            self.guest.setTags(tags, id=instance_id)
 
         if hostname:
             obj['hostname'] = hostname
@@ -558,14 +672,19 @@ class VSManager(utils.IdentifierMixin, object):
         return self.guest.editObject(obj, id=instance_id)
 
     def rescue(self, instance_id):
-        """ Reboot a VSI into the Xen recsue kernel
+        """Reboot a VSI into the Xen recsue kernel.
 
         :param integer instance_id: the instance ID to rescue
+        :returns: bool -- True or an Exception
+
+        Example::
+            # Puts instance 12345 into rescue mode
+            result = mgr.rescue(instance_id=12345)
         """
         return self.guest.executeRescueLayer(id=instance_id)
 
     def capture(self, instance_id, name, additional_disks=False, notes=None):
-        """ Capture one or all disks from a VS to a SoftLayer image.
+        """Capture one or all disks from a VS to a SoftLayer image.
 
         Parameters set to None will be ignored and not attempted to be updated.
 
@@ -575,13 +694,20 @@ class VSManager(utils.IdentifierMixin, object):
                                         attached storage devices
         :param string notes: notes about this particular image
 
+        :returns: dictionary -- information about the capture transaction.
+
+        Example::
+            name = "Testing Images"
+            notes = "Some notes about this image"
+            result = mgr.capture(instance_id=12345, name=name, notes=notes)
         """
         vsi = self.get_instance(instance_id)
 
         disk_filter = lambda x: x['device'] == '0'
-        # Disk 1 is swap partition.  Need to skip its capture.
+        # Skip disk 1 (swap partition) and CD mounts
         if additional_disks:
-            disk_filter = lambda x: x['device'] != '1'
+            disk_filter = lambda x: (str(x['device']) != '1' and
+                                     x['mountType'] != 'CD')
 
         disks = [block_device for block_device in vsi['blockDevices']
                  if disk_filter(block_device)]
@@ -591,8 +717,15 @@ class VSManager(utils.IdentifierMixin, object):
 
     def upgrade(self, instance_id, cpus=None, memory=None,
                 nic_speed=None, public=True):
-        """
-        Upgrades a VS instance
+        """Upgrades a VS instance.
+
+        Example::
+
+           # Upgrade instance 12345 to 4 CPUs and 4 GB of memory
+           import SoftLayer
+           client = SoftLayer.create_client_from_env()
+           mgr = SoftLayer.VSManager(client)
+           mgr.upgrade(12345, cpus=4, memory=4)
 
         :param int instance_id: Instance id of the VS to be upgraded
         :param int cpus: The number of virtual CPUs to upgrade to
@@ -601,44 +734,45 @@ class VSManager(utils.IdentifierMixin, object):
         :param int memory: RAM of the VS to be upgraded to.
         :param int nic_speed: The port speed to set
 
-        ::
-
-           # Upgrade instance 12345 to 4 CPUs and 4 GB of memory
-           import SoftLayer
-           client = SoftLayer.Client(config="~/.softlayer")
-
-           mgr = SoftLayer.VSManager(client)
-           mgr.upgrade(12345, cpus=4, memory=4)
-
+        :returns: bool
         """
         package_items = self._get_package_items()
-        item_id = []
+        prices = []
         if cpus:
-            item_id.append({'id': self._get_item_id_for_upgrade(
-                package_items, 'cpus', cpus, public)})
+            prices.append({
+                'id': self._get_item_id_for_upgrade(package_items,
+                                                    'cpus',
+                                                    cpus,
+                                                    public)})
         if memory:
-            item_id.append({'id': self._get_item_id_for_upgrade(
-                package_items, 'memory', memory)})
+            prices.append({
+                'id': self._get_item_id_for_upgrade(package_items,
+                                                    'memory',
+                                                    memory)})
         if nic_speed:
-            item_id.append({'id': self._get_item_id_for_upgrade(
-                package_items, 'nic_speed', nic_speed)})
+            prices.append({
+                'id': self._get_item_id_for_upgrade(package_items,
+                                                    'nic_speed',
+                                                    nic_speed)})
 
-        order = {}
-        order['complexType'] = (
-            'SoftLayer_Container_Product_Order_Virtual_Guest_Upgrade')
-        order['virtualGuests'] = [{'id': int(instance_id)}]
-        order['prices'] = item_id
-        order['properties'] = [{'name': 'MAINTENANCE_WINDOW',
-                                'value': str(datetime.datetime.now())}]
-        if cpus or memory or nic_speed:
+        maintenance_window = datetime.datetime.now(utils.UTC())
+        order = {
+            'complexType': 'SoftLayer_Container_Product_Order_Virtual_Guest_'
+                           'Upgrade',
+            'prices': prices,
+            'properties': [{
+                'name': 'MAINTENANCE_WINDOW',
+                'value': maintenance_window.strftime("%Y-%m-%d %H:%M:%S%z")
+            }],
+            'virtualGuests': [{'id': int(instance_id)}],
+        }
+        if prices:
             self.client['Product_Order'].placeOrder(order)
             return True
         return False
 
     def _get_package_items(self):
-        """
-        Following Method gets all the item ids related to VS
-        """
+        """Following Method gets all the item ids related to VS."""
         mask = "mask[description,capacity,prices[id,categories[name,id]]]"
         package_type = "VIRTUAL_SERVER_INSTANCE"
         package_id = self.ordering_manager.get_package_id_by_type(package_type)
@@ -648,8 +782,8 @@ class VSManager(utils.IdentifierMixin, object):
 
     def _get_item_id_for_upgrade(self, package_items, option, value,
                                  public=True):
-        """
-        Find the item ids for the parameters you want to upgrade to.
+        """Find the item ids for the parameters you want to upgrade to.
+
         :param list package_items: Contains all the items related to an VS
         :param string option: Describes type of parameter to be upgraded
         :param int value: The value of the parameter to be upgraded
