@@ -1,22 +1,24 @@
 """
     SoftLayer.utils
     ~~~~~~~~~~~~~~~
-    Utility function/classes
+    Utility function/classes.
 
     :license: MIT, see LICENSE for more details.
 """
+import datetime
 import re
 
 import six
 
+# pylint: disable=pointless-except, no-member, invalid-name
+
 UUID_RE = re.compile(r'^[0-9a-f\-]{36}$', re.I)
 KNOWN_OPERATIONS = ['<=', '>=', '<', '>', '~', '!~', '*=', '^=', '$=', '_=']
 
-configparser = six.moves.configparser  # pylint: disable=E1101,C0103
-console_input = six.moves.input  # pylint: disable=E1101,C0103
-string_types = six.string_types  # pylint: disable=C0103
-StringIO = six.StringIO  # pylint: disable=C0103
-xmlrpc_client = six.moves.xmlrpc_client  # pylint: disable=E1101,C0103
+configparser = six.moves.configparser
+string_types = six.string_types
+StringIO = six.StringIO
+xmlrpc_client = six.moves.xmlrpc_client
 
 
 def lookup(dic, key, *keys):
@@ -111,6 +113,25 @@ def query_filter(query):
     return {'operation': query}
 
 
+def query_filter_date(start, end):
+    """Query filters given start and end date.
+
+    :param start:YY-MM-DD
+    :param end: YY-MM-DD
+    """
+    sdate = datetime.datetime.strptime(start, "%Y-%m-%d")
+    edate = datetime.datetime.strptime(end, "%Y-%m-%d")
+    startdate = "%s/%s/%s" % (sdate.month, sdate.day, sdate.year)
+    enddate = "%s/%s/%s" % (edate.month, edate.day, edate.year)
+    return {
+        'operation': 'betweenDate',
+        'options': [
+            {'name': 'startDate', 'value': [startdate+' 0:0:0']},
+            {'name': 'endDate', 'value': [enddate+' 0:0:0']}
+        ]
+    }
+
+
 class IdentifierMixin(object):
     """Mixin used to resolve ids from other names of objects.
 
@@ -156,3 +177,16 @@ def resolve_ids(identifier, resolvers):
             return ids
 
     return []
+
+
+class UTC(datetime.tzinfo):
+    """UTC timezone."""
+
+    def utcoffset(self, _):
+        return datetime.timedelta(0)
+
+    def tzname(self, _):
+        return "UTC"
+
+    def dst(self, _):
+        return datetime.timedelta(0)
