@@ -18,10 +18,10 @@ def upload():
 
 def clean():
     puts("* Cleaning Repo")
-    dirs = ['.tox', 'SoftLayer.egg-info', 'build', 'dist']
-    for d in dirs:
-        if os.path.exists(d) and os.path.isdir(d):
-            shutil.rmtree(d)
+    directories = ['.tox', 'SoftLayer.egg-info', 'build', 'dist']
+    for directory in directories:
+        if os.path.exists(directory) and os.path.isdir(directory):
+            shutil.rmtree(directory)
 
 
 def release(version, force=False):
@@ -37,8 +37,8 @@ def release(version, force=False):
     clean()
 
     puts(" * Tagging Version %s" % version_str)
-    f = 'f' if force else ''
-    local("git tag -%sam \"%s\" %s" % (f, version_str, version_str))
+    force_option = 'f' if force else ''
+    local("git tag -%sam \"%s\" %s" % (force_option, version_str, version_str))
 
     local("pip install wheel")
 
